//--------------------------------------------------------------//
// Vars
//--------------------------------------------------------------//

float4x4 viewMatrix : VIEW;
float4x4 worldMatrix : WORLD;
float4x4 viewProjMatrix : VIEWPROJECTION;
float4x4 projMatrix: PROJECTION;
float4x4 worldViewProjMatrix: WORLDVIEWPROJECTION;

texture Tex <string uiname="Texture";>;
texture Tex2 <string uiname="Texture2";>;

//--------------------------------------------------------------//
// texture
//--------------------------------------------------------------//

sampler Displacement = sampler_state    //sampler for doing the texture-lookup
{
    Texture   = (Tex2);          //apply a texture to the sampler
    MipFilter = POINT;         //sampler states
    MinFilter = POINT;
    MagFilter = POINT;
};

sampler Samp = sampler_state    //sampler for doing the texture-lookup
{
    Texture   = (Tex);          //apply a texture to the sampler
  MipFilter = LINEAR; //sampler states
  MinFilter = LINEAR;
  MagFilter = LINEAR;
};


//--------------------------------------------------------------
// Vertex Shaders
//--------------------------------------------------------------
struct VS_OUTPUT {
   float4 Pos:     POSITION;
   float2 TexCood: TEXCOORD0;

};

VS_OUTPUT VS(float4 pos: POSITION, float3 normal: NORMAL, float2 TexCood: TEXCOORD0)
{
   VS_OUTPUT Out;

   //displacement with texture
   float4 displacedPos;
   float displaceVal = tex2Dlod(Displacement, float4(TexCood.x, TexCood.y,  0,0));
   displacedPos = pos;
   float zDisplacement = ( 15*displaceVal);
   displacedPos.z = pos.z + displaceVal;

   Out.Pos = mul(displacedPos, worldViewProjMatrix);
   Out.TexCood = TexCood;
   
   return Out;
}

//--------------------------------------------------------------
// Pixel Shaders
//--------------------------------------------------------------

float4 PS(float2 TexCood: TEXCOORD0) : COLOR
{
   float4 col = tex2D(Samp, TexCood);
   return col;
}

//--------------------------------------------------------------
// Technique
//--------------------------------------------------------------

technique TVertexAndPixelShader
{
    pass P0
    {
        // Render States
        fillMode = solid;
        // Shaders Declaration
        VertexShader = compile vs_3_0 VS();
        PixelShader  = compile ps_3_0 PS();
    }  
}
